==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/informix/informix/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Kinfxdb Informix driver")
url = "http://thor.prohosting.com/~alexan/pub/Kinfxdb/"
doc = """
Description
-----------
Written by Alexander Kuznetsov, kinfxdb provides support for Informix.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP


Connection Properties
---------------------
* host       -- This is the hostname running Informix (required)
* dbname     -- This is the Informix database to use (required)

Examples
--------
  [myconn]
  provider=informix       # Use the Kinfxdb adapter
  host=localhost          # The hostname/IP of the Informix host
  dbname=mydb             # The name of the Informix database

Notes
-----
1. This driver has not been fully tested.  If you are successfully using
   this driver, please let us know.

2. This driver does not yet support schema introspection, so you will not
   be able to use Wizards in GNUe Designer.
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/informix/informix/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Kinfxdb Informix driver")
url = "http://thor.prohosting.com/~alexan/pub/Kinfxdb/"
doc = """
Description
-----------
Written by Alexander Kuznetsov, kinfxdb provides support for Informix.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP


Connection Properties
---------------------
* host       -- This is the hostname running Informix (required)
* dbname     -- This is the Informix database to use (required)

Examples
--------
  [myconn]
  provider=informix       # Use the Kinfxdb adapter
  host=localhost          # The hostname/IP of the Informix host
  dbname=mydb             # The name of the Informix database

Notes
-----
1. This driver is currently unmaintained and not functional.
"""
